@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: monad-logger
 version: 0.3.18
-id: monad-logger-0.3.18-0974645d267a817a7b3484945a31ce66
-key: monad_C35svQH7cmcFF0rmqB4WW2
+id: monad-logger-0.3.18-e41795701bd26d2e948311dc59f0bce2
+key: monad_DbcKrxDze5S3VCM36SWCBu
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/kazu-yamamoto/logger
@@ -19,13 +19,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/monad-logger-0.3.18
 library-dirs: /usr/lib/ghc-7.10.3/site-local/monad-logger-0.3.18
 data-dir: /usr/share/arm-linux-ghc-7.10.3/monad-logger-0.3.18
-hs-libraries: HSmonad-logger-0.3.18-C35svQH7cmcFF0rmqB4WW2
+hs-libraries: HSmonad-logger-0.3.18-DbcKrxDze5S3VCM36SWCBu
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.11-ff8bfc3f034dbe9a6e5b1cd3f1929886
+    conduit-extra-1.1.13.1-9eaf94b1885f7c12e1eeebbc86766f62
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
     fast-logger-2.4.1-5b4c33804a079c795a3744fd9f8cdcd3
     lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
